pub async fn drive_stream( renderer: Box<dyn OutputRenderer>, events: BoxStream<'static, BuildEvent>, )
Drive a renderer from a Stream of events until it ends or a BuildEnd is seen.
Stream
BuildEnd
The hm-exec backend handle yields events as a BoxStream<'static, BuildEvent>; this function is the counterpart to drive for that case.
hm-exec
BoxStream<'static, BuildEvent>
drive